#
# spec file for package python-jsonschema-path
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-jsonschema-path
Version:        0.3.3
Release:        1.1
Summary:        JSONSchema Spec with object-oriented paths
License:        Apache-2.0
URL:            https://github.com/p1c2u/jsonschema-path
Source:         https://github.com/p1c2u/jsonschema-path/archive/refs/tags/%{version}.tar.gz#/jsonschema-path-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module PyYAML >= 5.1}
BuildRequires:  %{python_module pathable >= 0.4.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module referencing >= 0.28.0}
BuildRequires:  %{python_module requests >= 2.31.0}
BuildRequires:  %{python_module responses >= 0.23.0}
# /SECTION
Requires:       python-PyYAML >= 5.1
Requires:       python-pathable >= 0.4.1
Requires:       python-referencing >= 0.28.0
Suggests:       python-requests >= 2.31.0
Provides:       python-jsonschema_path = %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
JSONSchema Spec with object-oriented paths.

%prep
%setup -q -n jsonschema-path-%{version}
# unpin and hope for the best
sed -i '/referencing/ s/,<0.30.0//' pyproject.toml
# Remove need to pytest-cov
sed -i '/--cov/d' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/jsonschema_path
%{python_sitelib}/jsonschema_path-%{version}.dist-info

%changelog
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 0.3.3:
  * Relax dependency constraint to support referencing 0.35 #138
* Sun Dec 17 2023 Dirk Müller <dmueller@suse.com>
- update to 0.3.2:
  * Manifest py.typed fix #93
  * Use contents method #94
  * Bump referencing version limit to 0.31 #92
  * SchemaPath `contents` method added #79
  * This version changes project and package name from
    jsonschema-spec to jsonschema-path.
  * `exists` and `as_uri` path methods added #72
  * Python 3.12 support #43
  * Allow set verify to requests handler #74
  * Accessor store resolved references fix #58
* Wed Jul 19 2023 Ben Greiner <code@bnavigator.de>
- Cleanup requirements
- Unpin referencing <0.30.0 because it was updated a few hours ago
* Wed Jul 19 2023 ecsos <ecsos@opensuse.org>
- Update to 0.2.3
  - FilePathReader read relative path fix #39
- Update to 0.2.2
  - Add resolve context method for SchemaPath #31
- Update to 0.2.1
  - Bump referencing from 0.24.4 to 0.29.0 #25
- Update to 0.2.0
  - Python 3.7 support dropped #23
  - Remove jsonschema dependency in favor of referencing and jsonschema-specifications #12
  - SchemaPath.from_path factory method added
  + Deprecations
  - Spec class name is deprecated. Use SchemaPath instead.
  - spec_url parameter is deprecated. Use base_uri instead.
  - ref_resolver_handlers parameter is deprecated. Use handlers instead.
- Fix not installable because of newer python-jsonschema requirement.
* Mon Jun 19 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.1.6:
  * lock typing-extensions just for python37 #22
  * add python 3.11 support #10
  * supports read protocol check fix #21
* Tue Jun 13 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue May  9 2023 Ben Greiner <code@bnavigator.de>
- Update requirements:
  * jsonschema has upper limit
  * poetry-core is enough to build
* Sun Mar 26 2023 Dirk Müller <dmueller@suse.com>
- update to 0.1.4:
  * jsonschema 4.17 dependency limit
  * Apache license spdx conformity
  * yaml loader timestamps fix
* Sat Sep 17 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v0.1.2
* Mon Sep  5 2022 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.1.1
